"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.structure = void 0;
const schematics_1 = require("@angular-devkit/schematics");
const schematics_utilities_1 = require("schematics-utilities");
const cdk_1 = require("schematics-utilities/dist/cdk");
function structure(options) {
    return (tree, _context) => {
        const workspace = schematics_utilities_1.getWorkspace(tree);
        const projectName = options.project;
        const workspaceProject = schematics_utilities_1.getProjectFromWorkspace(workspace, projectName);
        const projectPath = schematics_utilities_1.buildDefaultPath(workspaceProject);
        const templateSource = schematics_1.apply(schematics_1.url('./files'), [
            schematics_1.applyTemplates(Object.assign({}, options)),
            schematics_1.move(projectPath)
        ]);
        return schematics_1.chain([
            schematics_1.mergeWith(templateSource),
            addCoreModule(options)
        ]);
    };
}
exports.structure = structure;
/* https://github.com/nitayneeman/schematics-utilities/issues/23 */
function addModuleImportToRootModule(host, moduleName, src, project) {
    const modulePath = schematics_utilities_1.getAppModulePath(host, cdk_1.getProjectMainFile(project));
    const moduleSource = schematics_utilities_1.getSourceFile(host, modulePath);
    if (!moduleSource) {
        throw new schematics_1.SchematicsException(`Module not found: ${modulePath}`);
    }
    const changes = schematics_utilities_1.addImportToModule(moduleSource, modulePath, moduleName, src);
    const recorder = host.beginUpdate(modulePath);
    changes.forEach(change => {
        {
            recorder.insertLeft(change.pos, change.toAdd);
        }
    });
    host.commitUpdate(recorder);
}
function addCoreModule(options) {
    return (host) => {
        const workspace = schematics_utilities_1.getWorkspace(host);
        const workspaceProject = schematics_utilities_1.getProjectFromWorkspace(workspace, options.project);
        addModuleImportToRootModule(host, 'CoreModule', './core/core.module', workspaceProject);
        return host;
    };
}
//# sourceMappingURL=index.js.map